Coverage for scipy\version.py: 0%

# Coverage for scipy\version.py : 0%

## 7 statements 0 run 7 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 | # THIS FILE IS GENERATED FROM SCIPY SETUP.PY short_version = '1.3.0' version = '1.3.0' full_version = '1.3.0' git_revision = 'e1e44d12637997606b1bcc0c6de232349e11eee0' release = True if not release: version = full_version